@@ -4,32 +4,23 @@
 #> open https://flavjack.github.io/GerminaR/
 #> open https://flavjack.shinyapps.io/germinaquant/
 #> author .: Flavio Lozano-Isla (lozanoisla.com)
-#> date .: 2020-10-18
+#> date .: 2021-04-20
 # -------------------------------------------------------------------------
 
 # -------------------------------------------------------------------------
 # packages ----------------------------------------------------------------
 # -------------------------------------------------------------------------
 
-if (file.exists("setup.R")) { source("setup.R") }
+#> devtools::install_github("flavjack/GerminaR")
 
-library(GerminaR)
-library(shiny)
-library(metathis)
-library(tidyverse)
-library(shinydashboard)
-library(shinyWidgets)
-library(gsheet)
-library(readxl)
-library(ggpubr)
-library(DT)
+source("pkgs.R")
 
 # app ---------------------------------------------------------------------
 # -------------------------------------------------------------------------
 
-shinyUI(dashboardPage(skin = "green",
+shinyUI(dashboardPage(skin = "green", 
 
-    dashboardHeader(title = "GerminaQuant"),
+    dashboardHeader(title = "GerminaQuant • app"),
 
 # Sider -------------------------------------------------------------------
 
@@ -39,7 +30,7 @@ shinyUI(dashboardPage(skin = "green",
         menuItem("Presentacion", tabName = "intro", icon = icon("home")),
         menuItem("Fieldbook", tabName = "fieldbook", icon = icon("file-alt")),
         menuItem("Germination", tabName = "germination", icon = icon("seedling")),
-        menuItem("Box plot", tabName = "outlier", icon = icon("search")),
+        menuItem("Exploratory", tabName = "outlier", icon = icon("search")),
         menuItem("Statistics", tabName = "stat", icon = icon("pie-chart")),
         menuItem("Graphics", tabName = "graph", icon = icon("tint")),
         menuItem("Intime", tabName = "germint", icon = icon("hourglass")),
@@ -83,7 +74,7 @@ shinyUI(dashboardPage(skin = "green",
                   
                   HTML('
                   <p>
-                  <strong>GerminaQuant</strong> for R is web application based in R,
+                  <strong>GerminaQuant</strong> for R is a web application based in R,
                   you can use the app in your desktop installing the <em><strong>GerminaR</strong></em> package:
                   </p>
                   Install the package in the R console
@@ -96,26 +87,27 @@ shinyUI(dashboardPage(skin = "green",
                   <code>GerminaR::GerminaQuant()</code>
                   <br>
                   <br>
+                  
                   <div id=footer style="width:100%; margin:auto;">
-                  <div style="display:inline-block; width:49%">
+
+                  <div style="display:inline-block; width:48%">
                   <p style="text-align:center">
-                  <a target="_blank" href="https://CRAN.R-project.org/package=GerminaR"><img src="https://flavjack.github.io/GerminaR/reference/figures/logo.png" style="height:80px" title="R cran" alt="GerminaR"></a> 
+                  <a target="_blank" href="https://flavjack.github.io/GerminaR/"><img src="https://pkgdown.r-lib.org/reference/figures/logo.png" style="height:75px" title="GerminaR" alt="GerminaR"></a> 
                   <span style="display:block;"><small>GerminaR</small></span>
                   </p></div>
                   
-                  <div style="display:inline-block; width:49%">
+                  <div style="display:inline-block; width:48%">
                   <p style="text-align:center">
-                  <a target="_blank" href="https://flavjack.shinyapps.io/germinaquant/"><img src="https://flavjack.github.io/GerminaR/reference/figures/germinaquant.png" style="height:70px" title="GerminaQuant" alt="GerminaQuant for R"></a>
-                  <span style="display:block;"><small>GerminaQuant</small></span>
+                  <a target="_blank" href="https://youtube.com/playlist?list=PLSQMdOu57lj9QUoA6JLuv0nBTYacuyrbg"><img src="https://github.com/Flavjack/inti/raw/master/man/figures/youtube.png" style="height:70px" title="Demo" alt="Demo"></a> 
+                  <span style="display:block;"><small>Demo</small></span>
                   </p></div>
-
+              
                   </div>
                     
                   ')
 
                 ),
 
-
                 box(width = 5, 
                     title = "Characteristics", 
                     status = "danger",
@@ -161,16 +153,22 @@ shinyUI(dashboardPage(skin = "green",
                        
                       <div id=footer style="width:100%; margin:auto;">
 
-                      <div style="display:inline-block; width:49%">
+                      <div style="display:inline-block; width:32%">
                       <p style="text-align:center">
                       <a target="_blank" href="https://github.com/Flavjack/GerminaR"><img src="https://image.flaticon.com/icons/svg/25/25231.svg" style="height:70px" title="Github" alt="Github"></a>
                       <span style="display:block;"><small>Github</small></span>
                       </p></div>
                       
-                      <div style="display:inline-block; width:49%">
+                      <div style="display:inline-block; width:32%">
                       <p style="text-align:center">
-                      <a target="_blank" href="https://flavjack.github.io/GerminaR/"><img src="https://pkgdown.r-lib.org/reference/figures/logo.png" style="height:75px" title="GerminaR" alt="GerminaR"></a> 
-                      <span style="display:block;"><small>Project</small></span>
+                      <a target="_blank" href="https://CRAN.R-project.org/package=GerminaR"><img src="https://flavjack.github.io/GerminaR/reference/figures/logo.png" style="height:80px" title="R cran" alt="GerminaR"></a> 
+                      <span style="display:block;"><small>CRAN</small></span>
+                      </p></div>
+                  
+                      <div style="display:inline-block; width:32%">
+                      <p style="text-align:center">
+                      <a target="_blank" href="https://flavjack.shinyapps.io/germinaquant/"><img src="https://flavjack.github.io/GerminaR/reference/figures/germinaquant.png" style="height:70px" title="GerminaQuant" alt="GerminaQuant for R"></a>
+                      <span style="display:block;"><small>GerminaQuant</small></span>
                       </p></div>
                       
                       </div>
@@ -287,7 +285,7 @@ shinyUI(dashboardPage(skin = "green",
           
           box(width = 12,
               
-              dataTableOutput("summary")
+              DT::dataTableOutput("summary")
               
           )   
           
@@ -299,7 +297,7 @@ shinyUI(dashboardPage(skin = "green",
 
         tabItem(tabName = "outlier",
 
-          box(width = 10, background = "black",
+          box(width = 6, background = "black",
 
                     column(width = 4,
 
@@ -344,35 +342,94 @@ shinyUI(dashboardPage(skin = "green",
 
           ),
 
-          box(width = 2, background = "black",
+          box(width = 3, background = "black",
 
 
-            column(width = 12,
+            column(width = 6,
 
-              numericInput(
-                inputId ="bpbrk",
-                label = "Axis brake",
-                value = NA)
+              textInput(
+                inputId ="bpbrk"
+                , label = "Y limits"
+                , value = NULL
+                , placeholder = "0*100*20"
+                )
 
             ),
+            
+            column(width = 6,
+                   
+                   textInput(
+                     inputId ="bprot"
+                     , label = "X rotation"
+                     , value = "0*0.5*0.5"
+                     , placeholder = "angle*h*v"
+                   )
+                   
+            ),
 
             column(width = 12,
-
-              numericInput(
-                inputId ="bpsize",
-                label = "Size",
-                value = 2,
-                min = 0,
-                step = 0.1)
+              
+              textInput(
+                inputId ="bpopt"
+                , label = "Opt"
+                , placeholder = "extra layer"
+                )
             )
 
             ),
-
+          
+          
+          box(width = 3, background = "black",
+              
+              
+              column(width = 6,
+                     
+                     numericInput(
+                       inputId ="bpwd"
+                       , label = "Width (cm)"
+                       , value = 20
+                       , step = 2
+                     )
+                     
+              ),
+              
+              column(width = 6,
+                     
+                     numericInput(
+                       inputId = "bphg"
+                       , label = "Height (cm)"
+                       , value = 10
+                       , step = 2
+                     )
+                     
+              ),
+              
+              column(width = 6,
+                     
+                     numericInput(
+                       inputId ="bprs"
+                       , label = "Resolution (dpi)"
+                       , value = 100
+                       , step = 50
+                     )
+                     
+              ),
+              
+              column(width = 6,
+                     
+                     selectInput(
+                       inputId = "bplg"
+                       , label = "Legend"
+                       , choices = c("top", "bottom", "left", "right", "none")
+                       )
+                     ),
+              ),
+          
           shiny::fluidRow(
           
           box(width = 12,
-
-          plotOutput("boxplot")
+              
+              div(imageOutput("boxplot"), align = "center")
 
           )
           
@@ -435,8 +492,7 @@ shinyUI(dashboardPage(skin = "green",
             
             column(width = 12,
                    
-                   tableOutput("stat_summary")
-                   
+                   DT::dataTableOutput("stat_summary")
             )
 
           ),
@@ -477,172 +533,198 @@ shinyUI(dashboardPage(skin = "green",
 
         tabItem(tabName = "graph",
                 
-                
           fluidRow(
                 
-          column( width = 10,
+          column( width = 12,
 
-            box(width = 5, title = NULL, background = "blue",
-
-                      column(width = 12,
-
-                        textInput(
+            box(width = 6, title = NULL, background = "blue",
+                
+                column(width = 4,
+                       
+                       textInput(
                           inputId ="plot_ylab",
                           label = "Y label")
 
                       ),
+                
+                column(width = 4,
 
-                      column(width = 4,
-
-                        numericInput(
-                          inputId ="plot_ybrakes",
-                          label = "Brakes",
-                          value = NA,
-                          min = 0
-                        )
+                        textInput(inputId ="plot_xlab", label = "X label")
 
                       ),
+                
+                column(width = 4,
+                       
+                       textInput(inputId ="plot_glab"
+                                 , label = "Group label")
+                       
+                ),
+                
+                
+                column(width = 4),
+                
+                
+                column(width = 4,
 
-                      column(width = 4,
-
-                        numericInput(
-                          inputId ="plot_limit1",
-                          label = "Limit (i)",
-                          value = NA
-                        )
+                        textInput(inputId ="plot_xbrakes"
+                                  , label = "X brake labels (,)")
 
                       ),
+                
+                column(width = 4,
 
-                      column(width = 4,
-
-
-                        numericInput(
-                          inputId ="plot_limit2",
-                          label = "Limit (f)",
-                          value = NA
-                        )
-
-                      )
+                      textInput(inputId ="plot_gbrakes"
+                                , label = "Group brake labels (,)")
 
+                    ),
+                
               ),
 
-            box(width = 4, title = NULL, background = "green",
-
-                  column(width = 12,
-
-                    textInput(inputId ="plot_xlab", label = "X label")
-
-                  ),
-
-                  column(width = 12,
-
-                    textInput(inputId ="plot_xbrakes", label = "Brake labels")
-
-                  )
 
+            
+            box(width = 3, background = "black",
+                
+                
+                column(width = 6,
+                       
+                       textInput(
+                         inputId ="plot_ylimits"
+                         , label = "Y limits"
+                         , value = NULL
+                         , placeholder = "0*100*20"
+                       )
+                       
+                ),
+                
+                column(width = 6,
+                       
+                       textInput(
+                         inputId ="plot_xrotation"
+                         , label = "X rotation"
+                         , value = "0*0.5*0.5"
+                         , placeholder = "angle*h*v"
+                       )
+                       
+                ),
+                
+                column(width = 12,
+                       
+                       textInput(
+                         inputId ="plot_opt"
+                         , label = "Opt"
+                         , placeholder = "extra layer"
+                       )
+                )
+                
             ),
-
-            box(width = 3, background = "red",
-
-                  column(width = 12,
-
-                    textInput(inputId ="plot_glab", label = "Groups label")
-
-                  ),
+            
+            box(width = 3, background = "black",
+                
+                column(width = 6,
+                       
+                       numericInput(
+                         inputId ="plot_width"
+                         , label = "Width (cm)"
+                         , value = 20
+                         , step = 2
+                       )
+                       
+                ),
+                
+                column(width = 6,
+                       
+                       numericInput(
+                         inputId = "plot_height"
+                         , label = "Height (cm)"
+                         , value = 10
+                         , step = 2
+                       )
+                       
+                ),
+                
+                column(width = 6,
+                       
+                       numericInput(
+                         inputId ="plot_res"
+                         , label = "Resolution (dpi)"
+                         , value = 100
+                         , step = 50
+                       )
+                       
+                ),
+                
+                column(width = 6,
+                       
+                       selectInput(
+                         inputId = "plot_legend"
+                         , label = "Legend"
+                         , choices = c("top"
+                                       , "bottom"
+                                       , "left"
+                                       , "right"
+                                       , "none")
+                       )
+                ),
+            ),
+            
+            shiny::fluidRow(
+              
+              box(width = 10,
+                  
+                  div(imageOutput("plotgr"), align = "center")
+                  
+              ), 
+              
+              column(width = 2,
 
                 column(width = 12,
 
-                  textInput(inputId ="plot_gbrakes", label = "Brake labels")
+                  radioButtons(
+                    inputId ="plot_type",
+                    label = "Type",
+                    choices = c("bar", "line"),
+                    inline = TRUE
+                    )
+                ),
 
+                column(width = 12,
+
+                  radioButtons(
+                    inputId ="plot_color",
+                    label = "Color",
+                    choices = c("yes"
+                                , "no"
+                                ),
+                    inline = TRUE)
+                ),
+
+                column(width = 12,
+
+                  radioButtons(
+                    inputId ="plot_sig",
+                    label = "Significance",
+                    choices = c("yes" = "sig"
+                                , "no" 
+                                ),
+                    inline = TRUE)
+                ),
+
+                column(width = 12,
+
+                  radioButtons(
+                    inputId ="plot_error",
+                    label = "Error",
+                    choices = c("ste"
+                                , "std"
+                                ),
+                    inline = TRUE)
                 )
 
-            ),
-
-              div(imageOutput("plotgr"), align = "center")
+              )
+              
+            )
             
-            ),
-
-          column(width = 2,
-
-            column(width = 12,
-
-              radioButtons(
-                inputId ="plot_type",
-                label = "Type",
-                choices = c("bar", "line"),
-                inline = TRUE
-                )
-            ),
-
-            column(width = 12,
-
-              radioButtons(
-                inputId ="plot_color",
-                label = "Color",
-                choices = c("yes" = TRUE
-                            , "no" = FALSE
-                            ),
-                inline = TRUE)
-            ),
-
-            column(width = 12,
-
-              radioButtons(
-                inputId ="plot_sig",
-                label = "Significance",
-                choices = c("yes" = "sig"
-                            , "no"
-                            ),
-                inline = TRUE)
-            ),
-
-            column(width = 12,
-
-              radioButtons(
-                inputId ="plot_error",
-                label = "Error",
-                choices = c("ste"
-                            , "std"
-                            ),
-                inline = TRUE)
-            ),
-
-            column(width = 12,
-
-              selectInput(
-                inputId ="plot_legend",
-                label = "Legend",
-                choices = c("top", "bottom", "left", "right", "none")
-                )
-            ),
-            
-            column(width = 12,
-                   
-                   numericInput('plot_width', 'Width (cm)',
-                                value = 20,
-                                min = 5,
-                                step = 5)
-                   
-            ),
-
-            column(width = 12,
-
-              numericInput('plot_height', 'Height (cm)',
-                value = 10,
-                min = 5,
-                step = 5)
-             ),
-
-            column(width = 12,
-                   
-                   numericInput('plot_res', 'Resolution (dpi)',
-                                value = 100,
-                                min = 50,
-                                step = 50)
-                   
             )
-
-          )
           
           )
 
@@ -653,179 +735,201 @@ shinyUI(dashboardPage(skin = "green",
 
 tabItem(tabName = "germint",
         
-        column( width = 10,
-             
-             
-             box(width = 5, title = NULL, background = "blue",
-                 
-                 
-                 column(width = 12,
-                        
-                        textInput(
-                          inputId ="intime_ylab",
-                          label = "Y label",
-                          value = "Germination ('%')")
-                        
-                        
-                 ),
-                 
-                 column(width = 4,
-                        
-                        
-                        numericInput(
-                          inputId ="intime_ybrakes",
-                          label = "Brakes",
-                          value = NA,
-                          min = 0
-                        )
-                        
-                 ),
-                 
-                 
-                 column(width = 4,
-                        
-                        
-                        numericInput(
-                          inputId ="intime_limit1",
-                          label = "Limit (i)",
-                          value = NA
-                        )
-                        
-                 ),
-                 
-                 
-                 column(width = 4,
-                        
-                        
-                        numericInput(
-                          inputId ="intime_limit2",
-                          label = "Limit (f)",
-                          value = NA
-                        )
-                        
-                 )
-                 
-             ),
-             
-             box(width = 4, title = NULL, background = "green",
-                 
-                 column(width = 12,
-                        
-                        textInput(inputId ="intime_xlab", label = "X label", value = "Time")
-                        
-                        
-                 ),
-                 
-                 column(width = 12,
-                        
-                        textInput(inputId ="intime_xbrake", label = "Brake labels", value = "")
-                        
-                        
-                 )
-             ),
-             
-             
-             box(width = 3, background = "red",
-                 
-                 column(width = 12,
-                        
-                        textInput(inputId ="intime_glab", label = "Legend", value = "")
-                        
-                        
-                 ),
-                 
-                 
-                 column(width = 12,
-                        
-                        textInput(inputId ="intime_gbrakes", label = "Brake Text", value = "")
-                        
-                        
-                 )
-                 
-             ),
-             
-               div(imageOutput("intime_plot"), align = "center")
-
-        ),
         
-          column(width = 2,
-              
-              
-              column(width = 12,
-                     
-                     
-                     uiOutput('smvar')
-                     
-              ),
-              
-              column(width = 12,
-                     
-                     
-                     radioButtons(
-                       inputId ="intime_type",
-                       label = "Type",
-                       choices = c("percentage", "relative"),
-                       selected = "percentage",
-                       inline = F)
-              ),
-              
-              column(width = 12,
-              
-              radioButtons(
-                inputId ="intime_color",
-                label = "Color",
-                choices = c("yes" = TRUE
-                            , "no" = FALSE
-                ),
-                inline = TRUE),
-              
-              ),
-
-              column(width = 12,
-               
-               radioButtons(
-                 inputId ="intime_error",
-                 label = "Error",
-                 choices = c("ste"
-                             , "std"
-                 ),
-                 inline = TRUE)
-        ),
-        
-        column(width = 12,
-               
-               selectInput(
-                 inputId ="intime_legend",
-                 label = "Legend",
-                 choices = c("top", "bottom", "left", "right", "none")
-               )
-        ),
-        
-        column(width = 12,
-               
-               numericInput('intime_width', 'Width (cm)',
-                            value = 20,
-                            min = 5,
-                            step = 5)
-        ),
-        
-        column(width = 12,
-               
-               numericInput('intime_height', 'Height (cm)',
-                            value = 10,
-                            min = 5,
-                            step = 5)
-        ),
-        
-        column(width = 12,
-               
-               numericInput('intime_res', 'Resolution (dpi)',
-                            value = 100,
-                            min = 50,
-                            step = 50)
-               )
-        )
+        fluidRow(
           
+          column( width = 12,
+                  
+                  box(width = 6, title = NULL, background = "blue",
+                      
+                      column(width = 4,
+                             
+                             textInput(
+                               inputId ="intime_ylab",
+                               label = "Y label"
+                               , value = "Germination ('%')")
+                             
+                      ),
+                      
+                      column(width = 4,
+                             
+                             textInput(inputId ="intime_xlab"
+                                       , label = "X label"
+                                       , value = "Time")
+                             
+                      ),
+                      
+                      column(width = 4,
+                             
+                             textInput(inputId ="intime_glab"
+                                       , label = "Group label")
+                             
+                      ),
+                      
+                      
+                      column(width = 4),
+                      
+                      
+                      column(width = 4,
+                             
+                             textInput(inputId ="intime_xbrakes"
+                                       , label = "X brake labels (,)")
+                             
+                      ),
+                      
+                      column(width = 4,
+                             
+                             textInput(inputId ="intime_gbrakes"
+                                       , label = "Group brake labels (,)")
+                             
+                      ),
+                      
+                  ),
+                  
+                  
+                  
+                  box(width = 3, background = "black",
+                      
+                      
+                      column(width = 6,
+                             
+                             textInput(
+                               inputId ="intime_ylimits"
+                               , label = "Y limits"
+                               , value = NULL
+                               , placeholder = "0*100*20"
+                             )
+                             
+                      ),
+                      
+                      column(width = 6,
+                             
+                             textInput(
+                               inputId ="intime_xrotation"
+                               , label = "X rotation"
+                               , value = "0*0.5*0.5"
+                               , placeholder = "angle*h*v"
+                             )
+                             
+                      ),
+                      
+                      column(width = 12,
+                             
+                             textInput(
+                               inputId ="intime_opt"
+                               , label = "Opt"
+                               , placeholder = "extra layer"
+                             )
+                      )
+                      
+                  ),
+                  
+                  box(width = 3, background = "black",
+                      
+                      column(width = 6,
+                             
+                             numericInput(
+                               inputId ="intime_width"
+                               , label = "Width (cm)"
+                               , value = 20
+                               , step = 2
+                             )
+                             
+                      ),
+                      
+                      column(width = 6,
+                             
+                             numericInput(
+                               inputId = "intime_height"
+                               , label = "Height (cm)"
+                               , value = 10
+                               , step = 2
+                             )
+                             
+                      ),
+                      
+                      column(width = 6,
+                             
+                             numericInput(
+                               inputId ="intime_res"
+                               , label = "Resolution (dpi)"
+                               , value = 100
+                               , step = 50
+                             )
+                             
+                      ),
+                      
+                      column(width = 6,
+                             
+                             selectInput(
+                               inputId = "intime_legend"
+                               , label = "Legend"
+                               , choices = c("top"
+                                             , "bottom"
+                                             , "left"
+                                             , "right"
+                                             , "none")
+                             )
+                      ),
+                  ),
+                  
+                  shiny::fluidRow(
+                    
+                    box(width = 10,
+                        
+                        div(imageOutput("intime_plot"), align = "center")
+                        
+                    ), 
+                    
+                    column(width = 2,
+                           
+                           column(width = 12,
+                                  
+                                  uiOutput('smvar')
+
+                                 ),
+                           
+                           column(width = 12,
+
+
+                                  radioButtons(
+                                    inputId ="intime_type",
+                                    label = "Type",
+                                    choices = c("percentage", "relative"),
+                                    selected = "percentage",
+                                    inline = F)
+                           ),
+                           
+                           column(width = 12,
+                                  
+                                  radioButtons(
+                                    inputId ="intime_color",
+                                    label = "Color",
+                                    choices = c("yes"
+                                                , "no"
+                                    ),
+                                    inline = TRUE)
+                           ),
+                           
+                           column(width = 12,
+                                  
+                                  radioButtons(
+                                    inputId ="intime_error",
+                                    label = "Error",
+                                    choices = c("ste"
+                                                , "std"
+                                    ),
+                                    inline = TRUE)
+                           )
+                           
+                    )
+                    
+                  )
+                  
+          )
+          
+        )
+        
 ),
 
 # tools -------------------------------------------------------------------
